parser

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 7, 2026 License: MIT Imports: 17 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Parse

func Parse(ctx context.Context, importPaths []string, files []string) ([]model.File, error)

Parse compiles the given root proto files and maps them into the stage1 semantic model.

Types

type ParseError added in v0.3.0

type ParseError = errorx.Sentinel[parserTag]

ParseError is the domain error type for all parser constraint violations. Use errorx.NewSentinelf[parserTag] to create instances with runtime context.

Jump to